package javax.swing.colorchooser;

import java.awt.event.MouseEvent;
import java.io.Serializable;
import java.awt.event.MouseAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.KeyAdapter;
import javax.swing.JLabel;
import java.awt.Insets;
import javax.swing.border.CompoundBorder;
import javax.swing.border.LineBorder;
import java.awt.Color;
import java.awt.BorderLayout;
import javax.swing.JPanel;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.JColorChooser;
import javax.swing.Icon;
import javax.swing.UIManager;
import java.awt.event.KeyListener;
import java.awt.event.MouseListener;

class DefaultSwatchChooserPanel extends AbstractColorChooserPanel
{
    SwatchPanel swatchPanel;
    RecentSwatchPanel recentSwatchPanel;
    MouseListener mainSwatchListener;
    MouseListener recentSwatchListener;
    private KeyListener mainSwatchKeyListener;
    private KeyListener recentSwatchKeyListener;
    
    public DefaultSwatchChooserPanel() {
        this.setInheritsPopupMenu(true);
    }
    
    @Override
    public String getDisplayName() {
        return UIManager.getString("ColorChooser.swatchesNameText", this.getLocale());
    }
    
    @Override
    public int getMnemonic() {
        return this.getInt("ColorChooser.swatchesMnemonic", -1);
    }
    
    @Override
    public int getDisplayedMnemonicIndex() {
        return this.getInt("ColorChooser.swatchesDisplayedMnemonicIndex", -1);
    }
    
    @Override
    public Icon getSmallDisplayIcon() {
        return null;
    }
    
    @Override
    public Icon getLargeDisplayIcon() {
        return null;
    }
    
    @Override
    public void installChooserPanel(JColorChooser colorChooser) {
        super.installChooserPanel(colorChooser);
    }
    
    @Override
    protected void buildChooser() {
        String string = UIManager.getString("ColorChooser.swatchesRecentText", this.getLocale());
        GridBagLayout layout = new GridBagLayout();
        GridBagConstraints constraints = new GridBagConstraints();
        JPanel comp = new JPanel(layout);
        (this.swatchPanel = new MainSwatchPanel()).putClientProperty("AccessibleName", this.getDisplayName());
        this.swatchPanel.setInheritsPopupMenu(true);
        (this.recentSwatchPanel = new RecentSwatchPanel()).putClientProperty("AccessibleName", string);
        this.mainSwatchKeyListener = new DefaultSwatchChooserPanel.MainSwatchKeyListener();
        this.mainSwatchListener = new DefaultSwatchChooserPanel.MainSwatchListener();
        this.swatchPanel.addMouseListener(this.mainSwatchListener);
        this.swatchPanel.addKeyListener(this.mainSwatchKeyListener);
        this.recentSwatchListener = new DefaultSwatchChooserPanel.RecentSwatchListener();
        this.recentSwatchKeyListener = new DefaultSwatchChooserPanel.RecentSwatchKeyListener();
        this.recentSwatchPanel.addMouseListener(this.recentSwatchListener);
        this.recentSwatchPanel.addKeyListener(this.recentSwatchKeyListener);
        JPanel comp2 = new JPanel(new BorderLayout());
        CompoundBorder compoundBorder = new CompoundBorder(new LineBorder(Color.black), new LineBorder(Color.white));
        comp2.setBorder(compoundBorder);
        comp2.add(this.swatchPanel, "Center");
        constraints.anchor = 25;
        constraints.gridwidth = 1;
        constraints.gridheight = 2;
        Insets insets = constraints.insets;
        constraints.insets = new Insets(0, 0, 0, 10);
        comp.add(comp2, constraints);
        constraints.insets = insets;
        this.recentSwatchPanel.setInheritsPopupMenu(true);
        JPanel comp3 = new JPanel(new BorderLayout());
        comp3.setBorder(compoundBorder);
        comp3.setInheritsPopupMenu(true);
        comp3.add(this.recentSwatchPanel, "Center");
        JLabel comp4 = new JLabel(string);
        comp4.setLabelFor(this.recentSwatchPanel);
        constraints.gridwidth = 0;
        constraints.gridheight = 1;
        constraints.weighty = 1.0;
        comp.add(comp4, constraints);
        constraints.weighty = 0.0;
        constraints.gridheight = 0;
        constraints.insets = new Insets(0, 0, 0, 2);
        comp.add(comp3, constraints);
        comp.setInheritsPopupMenu(true);
        this.add(comp);
    }
    
    @Override
    public void uninstallChooserPanel(JColorChooser colorChooser) {
        super.uninstallChooserPanel(colorChooser);
        this.swatchPanel.removeMouseListener(this.mainSwatchListener);
        this.swatchPanel.removeKeyListener(this.mainSwatchKeyListener);
        this.recentSwatchPanel.removeMouseListener(this.recentSwatchListener);
        this.recentSwatchPanel.removeKeyListener(this.recentSwatchKeyListener);
        this.swatchPanel = null;
        this.recentSwatchPanel = null;
        this.mainSwatchListener = null;
        this.mainSwatchKeyListener = null;
        this.recentSwatchListener = null;
        this.recentSwatchKeyListener = null;
        this.removeAll();
    }
    
    @Override
    public void updateChooser() {
    }
    
    private class RecentSwatchKeyListener extends KeyAdapter
    {
        @Override
        public void keyPressed(KeyEvent keyEvent) {
            if (32 == keyEvent.getKeyCode()) {
                DefaultSwatchChooserPanel.this.setSelectedColor(DefaultSwatchChooserPanel.this.recentSwatchPanel.getSelectedColor());
            }
        }
    }
    
    private class MainSwatchKeyListener extends KeyAdapter
    {
        @Override
        public void keyPressed(KeyEvent keyEvent) {
            if (32 == keyEvent.getKeyCode()) {
                Color selectedColor = DefaultSwatchChooserPanel.this.swatchPanel.getSelectedColor();
                DefaultSwatchChooserPanel.this.setSelectedColor(selectedColor);
                DefaultSwatchChooserPanel.this.recentSwatchPanel.setMostRecentColor(selectedColor);
            }
        }
    }
    
    class RecentSwatchListener extends MouseAdapter implements Serializable
    {
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            if (DefaultSwatchChooserPanel.this.isEnabled()) {
                Color colorForLocation = DefaultSwatchChooserPanel.this.recentSwatchPanel.getColorForLocation(mouseEvent.getX(), mouseEvent.getY());
                DefaultSwatchChooserPanel.this.recentSwatchPanel.setSelectedColorFromLocation(mouseEvent.getX(), mouseEvent.getY());
                DefaultSwatchChooserPanel.this.setSelectedColor(colorForLocation);
                DefaultSwatchChooserPanel.this.recentSwatchPanel.requestFocusInWindow();
            }
        }
    }
    
    class MainSwatchListener extends MouseAdapter implements Serializable
    {
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            if (DefaultSwatchChooserPanel.this.isEnabled()) {
                Color colorForLocation = DefaultSwatchChooserPanel.this.swatchPanel.getColorForLocation(mouseEvent.getX(), mouseEvent.getY());
                DefaultSwatchChooserPanel.this.setSelectedColor(colorForLocation);
                DefaultSwatchChooserPanel.this.swatchPanel.setSelectedColorFromLocation(mouseEvent.getX(), mouseEvent.getY());
                DefaultSwatchChooserPanel.this.recentSwatchPanel.setMostRecentColor(colorForLocation);
                DefaultSwatchChooserPanel.this.swatchPanel.requestFocusInWindow();
            }
        }
    }
}
